# For Haskell Packaging Guidelines see:
# - https://fedoraproject.org/wiki/Packaging:Haskell
# - https://fedoraproject.org/wiki/PackagingDrafts/Haskell

%global pkg_name neither

%global common_summary Either with monad and applicative instances

%global common_description The standard Either datatype suffers from a lack of monad and \
applicative instances. To make matters worse, the mtl and \
transformers packages provide orphan instances which conflict \
with each other, as well as defining a transformer version \
which has an usually unnecessary superclass constraint. \
 \
Besides these annoyances, there is another issue: there exist \
two reasonable definitions of the Applicative instance for \
Either: one the holds onto only the first Left value, or one \
that appends all Left values together via a Monoid instance. \
The former is compatible with the monad instance, while the \
latter is not. \
 \
This package defines three datatypes, some helpers functions \
and instances. The data types are AEither, MEither and \
MEitherT. AEither provides an Applicative instance which \
appends Left values, MEither provides the monadic definition, \
and MEitherT is a monad transformer.

Name:           ghc-%{pkg_name}
Version:        0.3.0
Release:        1%{?dist}
Summary:        %{common_summary}

Group:          System Environment/Libraries
License:        BSD
# BEGIN cabal2spec
URL:            http://hackage.haskell.org/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz
ExclusiveArch:  %{ghc_arches}
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
%if %{undefined without_hscolour}
BuildRequires:  hscolour
%endif
# END cabal2spec

BuildRequires:  ghc-failure-prof
BuildRequires:  ghc-transformers-prof

%description
%{common_description}


%package -n ghc-%{pkg_name}-devel
Summary:        Development files for %{common_summary}
Group:          Development/Libraries
# BEGIN cabal2spec
%{?ghc_devel_requires}
Obsoletes:      ghc-%{pkg_name}-prof < %{version}-%{release}
Provides:       ghc-%{pkg_name}-prof = %{version}-%{release}
# END cabal2spec

%description -n ghc-%{pkg_name}-devel
%{common_description}

This package contains the development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%post -n ghc-%{pkg_name}-devel
%ghc_pkg_recache

%postun -n ghc-%{pkg_name}-devel
%ghc_pkg_recache


%if %{undefined ghc_without_shared}
%files -n ghc-%{pkg_name} -f ghc-%{pkg_name}.files
%endif

%files -n ghc-%{pkg_name}-devel -f ghc-%{pkg_name}-devel.files


%changelog
* Wed Oct 26 2011 Jens Petersen <petersen@redhat.com> - 0.3.0-1
- update to 0.3.0

* Mon Oct 24 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.2.0-1.3
- rebuild with new gmp without compat lib

* Fri Oct 21 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.2.0-1.2
- rebuild with new gmp without compat lib

* Tue Oct 11 2011 Peter Schiffer <pschiffe@redhat.com> - 0.2.0-1.1
- rebuild with new gmp

* Mon Jul 25 2011 Ben Boeckel <mathstuf@gmail.com> - 0.2.0-1
- Update to 0.2.0

* Mon Jul 25 2011 Ben Boeckel <mathstuf@gmail.com> - 0.1.0-6
- Update to cabal2spec-0.24

* Fri Jun 24 2011 Jens Petersen <petersen@redhat.com> - 0.1.0-5
- BR ghc-Cabal-devel instead of ghc-prof and use ghc_arches (cabal2spec-0.23.2)

* Thu Mar 10 2011 Fabio M. Di Nitto <fdinitto@redhat.com> - 0.1.0-4
- Enable build on sparcv9

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 15 2011 Ben Boeckel <mathstuf@gmail.com> - 0.1.0-2
- Update to cabal2spec-0.22.4
- Rebuild

* Sat Oct 30 2010 Ben Boeckel <mathstuf@gmail.com> - 0.1.0-1
- Update to 0.1.0

* Sat Sep 04 2010 Ben Boeckel <mathstuf@gmail.com> - 0.0.2-1
- Initial package

* Sat Sep  4 2010 Fedora Haskell SIG <haskell-devel@lists.fedoraproject.org> - 0.0.2-0
- initial packaging for Fedora automatically generated by cabal2spec-0.22.2
